/**
 * The App contains Header and Scheduler components and makes them to work together
 */
import React, { Fragment, useState, useRef, useEffect } from 'react';

import { BryntumDemoHeader, BryntumThemeCombo } from '@bryntum/schedulerpro-react';

import Scheduler from './components/Scheduler';
import Toolbar from './components/Toolbar';
import { generateResources } from './Generator';

import './App.scss';

const App = props => {
    // Scheduler ref forwarded to Scheduler component
    const schedulerRef = useRef(null);

    // Scheduler configuration
    const [schedulerConfig] = useState({
        resourceTimeRangesFeature: { disabled: true },
        timeRangesFeature: { disabled: true },
        dependenciesFeature: { disabled: true }
    });

    let mode = (new URLSearchParams(window.location.search))
        .get('mode') === 'vertical' ? 'vertical' : 'horizontal';

    useEffect(() => {
        if(schedulerRef.current?.instance) {
            generateResources(200, 5, schedulerRef.current.instance);
        }
    }, [schedulerRef]);

    return (
        <Fragment>
            {/* BryntumDemoHeader component is used for Bryntum example styling only and can be removed */}
            <BryntumDemoHeader children={<BryntumThemeCombo />} />
            <Toolbar schedulerRef={schedulerRef} mode={mode}></Toolbar>
            <Scheduler ref={schedulerRef} {...schedulerConfig} mode={mode} />
        </Fragment>
    );
};


export default App;
