/**
 * Scheduler Component
 */

// React libraries
import React, { forwardRef, useState } from 'react';
import { PropTypes } from 'prop-types';

// Bryntum libraries
import { BryntumSchedulerPro } from '@bryntum/schedulerpro-react';

// Application components
import DemoEvent from './DemoEvent';
import ProgressBar from './ProgressBar';

// Scheduler component
const Scheduler = forwardRef((props, schedulerRef) => {
  // Event renderer returns JSX with DemoEvent component
  const eventRenderer = ({
    eventRecord,
    resourceRecord,
    assignmentRecord,
    renderData,
  }) => {
    return (
      <DemoEvent
        key={assignmentRecord.id}
        eventRecord={eventRecord}
        resourceRecord={resourceRecord}
      ></DemoEvent>
    );
  };

  const syncData = ({ store, action, records }) => {
    if (store.id === 'events') {
      console.log(records);
      const data = records[0].data;
      console.log('action', action);
      switch (action) {
        case 'remove':
          console.log('remove');
          console.log('data', data);

          break;
        case 'update':
          console.log('update', data);

          break;
      }
    }
    // console.log(
    //   `${store.id} changed. The action was: ${action}. Changed records: `,
    //   records
    // );
  };
  // Scheduler config
  const [schedulerConfig] = useState({
    narrowEventWidth: props.mode === 'vertical' ? 500 : 20,
    mode: props.mode,
    eventRenderer,
    // rowHeight: 70,
    eventStyle: 'colored',
    resourceImagePath: './users',
    // dependenciesFeature: { disabled: true },
    resourceTimeRangesFeature: { disabled: true },
    // timeRangesFeature: {
    //   disabled: true,
    //   enableResizing: true,
    // },
    // nonWorkingTimeFeature: { disabled: true },
    eventNonWorkingTimeFeature: { disabled: true },
    columns: [
      {
        text: 'Staff',
        field: 'name',
        type: 'resourceInfo',
        htmlEncodeHeaderText: false,
        width: 200,
      },
      {
        text: 'Progress<div class="small-text">(React component)</div>',
        htmlEncodeHeaderText: false,
        width: 220,
        align: 'center',
        editor: false,
        // Using custom React component
        renderer: ({ record }) => (
          <ProgressBar
            bgcolor={record.color}
            completed={Math.ceil(Math.random() * 100)}
          />
        ),
      },
    ],
    timeZone: 'Europe/Berlin',

    barMargin: 2,
    rowHeight: 72,

    startDate: new Date(),
    endDate: new Date(2023, 5, 14),

    viewPreset: 'dayAndWeek',
    allowOverlap: true,
    infiniteScroll: true,
    zoomOnTimeAxisDoubleClick: false,
    zoomOnMouseWheel: false,
    eventMenuFeature: {
      disabled: true,
    },
    timeAxisHeaderMenuFeature: {
      disabled: true,
      items: {
        zoomLevel: false,
      },
    },
    scheduleMenuFeature: {
      disabled: true,
    },
    timeRangesFeature: {
      disabled: false,
      showCurrentTimeLine: true,
      showHeaderElements: true,
      enableResizing: true,
    },
    columnLinesFeature: {
      disabled: false,
    },
    eventResizeFeature: {
      disabled: false,
    },
    scheduleTooltipFeature: {
      disabled: true,
    },
    dependenciesFeature: {
      disabled: true,
    },
    nonWorkingTimeFeature: {
      disabled: false,
    },
    headerZoomFeature: {
      disabled: true,
    },
  });
  return (
    <BryntumSchedulerPro
      {...schedulerConfig}
      {...props}
      onDataChange={syncData}
      ref={schedulerRef}
    />
  );
});

Scheduler.propTypes = {
  eventRenderer: PropTypes.func,
  dependenciesFeature: PropTypes.object,
  resourceTimeRangesFeature: PropTypes.object,
  timeRangesFeature: PropTypes.object,
  nonWorkingTimeFeature: PropTypes.object,
  eventNonWorkingTimeFeature: PropTypes.object,
  columns: PropTypes.array,
};

Scheduler.defaultProps = {};

export default Scheduler;
